import { IGame } from './IGame';
import { GameSettings, GaSettings } from './types';
export declare abstract class GameBase implements IGame {
    private _step;
    private _actionStep;
    private _hasFinished;
    private readonly _gameSettings;
    private readonly _gaSettings;
    protected constructor();
    get step(): number;
    get actionStep(): number;
    get gameSettings(): GameSettings;
    get gaSettings(): GaSettings;
    private get stepLimit();
    get hasReached(): boolean;
    protected onFinished(): void;
    protected abstract getGameSettings(): GameSettings;
    protected abstract getGaSettings(): GaSettings;
    abstract clone(): IGame;
    action(index: number): Promise<void> | never;
    protected abstract performAction(index: number): Promise<void>;
    perceive(index: number): Promise<boolean> | never;
    protected abstract performPerceive(index: number): Promise<boolean>;
    actionExpression(index: number): string;
    perceiveExpression(index: number): string;
    protected correctionItemScale(): number;
    protected getCorrectionItemScore(): number;
    getScore(): number;
    protected abstract performGetScore(): number;
    private static getCanvas;
    draw(target: string | HTMLCanvasElement): void;
    protected preDrawPixels(pixels: Uint8ClampedArray): void;
    protected getBackgroundColor(): string;
    protected getPixelColor(x: number, y: number): [number, ...number[]] | undefined;
    protected parseColors(colors: [number, ...number[]]): {
        red: number;
        green: number;
        blue: number;
        alpha: number;
    };
    protected performDrawPixels(pixels: Uint8ClampedArray): void;
    protected performDraw(context: CanvasRenderingContext2D): void;
}
